@@ -8,12 +8,15 @@
 
 from __future__ import annotations
 
+import asyncio
 import logging
 import os
 import pathlib
 import warnings
+from copy import deepcopy
+from functools import partial
 
-from typing import TYPE_CHECKING, Optional
+from typing import TYPE_CHECKING, Any, Optional
 
 import numpy
 import pandas
@@ -22,6 +25,7 @@ from astropy.table import Table
 
 from clu.command import Command
 from clu.legacy.tron import TronConnection
+from coordio import transforms
 from coordio.defaults import calibration
 
 from jaeger import config, log
@@ -48,6 +52,14 @@ __all__ = ["FVC"]
 FVC_CONFIG = config["fvc"]
 
 
+# Create a coroutine out of the original plotFVCResults.
+plotFVCResultsCo = asyncio.coroutine(deepcopy(transforms.plotFVCResults))
+
+
+def plotFVCResultsMP(loop: asyncio.AbstractEventLoop, *args, **kwargs):
+    loop.create_task(plotFVCResultsCo(*args, **kwargs))  # type: ignore
+
+
 def get_transform(observatory: str):
     """Returns the correct coordio FVC transform class for the observatory."""
 
@@ -84,6 +96,8 @@ class FVC:
     fitrms: float
     k: float
 
+    ieb_data: dict[str, Any] = {}
+
     def __init__(self, site: str, command: Optional[Command[JaegerActor]] = None):
 
         if len(calibration.positionerTable) == 0:
@@ -137,6 +151,7 @@ class FVC:
         level: logging._Level = logging.INFO,
         to_log: bool = True,
         to_command: bool = True,
+        broadcast: bool = False,
     ):
         """Logs a message, including to the command if present."""
 
@@ -148,13 +163,13 @@ class FVC:
 
         if self.command and to_command:
             if level == logging.DEBUG:
-                self.command.debug(msg)
+                self.command.debug(msg, broadcast=broadcast)
             elif level == logging.INFO:
-                self.command.info(msg)
+                self.command.info(msg, broadcast=broadcast)
             elif level == logging.WARNING:
-                self.command.warning(msg)
+                self.command.warning(msg, broadcast=broadcast)
             elif level == logging.ERROR:
-                self.command.error(msg)
+                self.command.error(msg, broadcast=broadcast)
 
     async def expose(
         self,
@@ -227,6 +242,7 @@ class FVC:
         use_new_invkin: bool = True,
         plot: bool | str = False,
         outdir: str | None = None,
+        loop: asyncio.AbstractEventLoop | None = None,
     ) -> tuple[fits.ImageHDU, pandas.DataFrame, pandas.DataFrame | None]:
         """Processes a raw FVC image.
 
@@ -259,6 +275,9 @@ class FVC:
             Whether to save additional debugging plots along with the processed image.
             If ``plot`` is a string, it will be used as the directory to which to
             save the plots.
+        loop
+            The running event loop. Used to schedule the plotting of the FVC
+            transform fit as a task.
 
         Returns
         -------
@@ -339,6 +358,11 @@ class FVC:
         FVCTransform = get_transform(self.fps.observatory)
         self.log(f"Using FVC transform class {FVCTransform.__name__!r}.")
 
+        if loop:
+            # Monkeypatch plotFVCResults to use a task and do plotting asynchronously.
+            # It's important to override it here, when a loop already exists.
+            transforms.plotFVCResults = partial(plotFVCResultsMP, loop)
+
         fvc_transform = FVCTransform(
             image_data,
             positioner_df,
@@ -658,6 +682,7 @@ class FVC:
     async def write_proc_image(
         self,
         new_filename: Optional[str | pathlib.Path] = None,
+        broadcast: bool = False,
     ) -> fits.HDUList:  # pragma: no cover
         """Writes the processed image along with additional table data.
 
@@ -733,6 +758,8 @@ class FVC:
                     self.log(f"Failed getting IEB information: {err}", logging.WARNING)
                     break
 
+        self.ieb_data = ieb_data
+
         for key, val in ieb_data.items():
             proc_hdus[1].header[key] = val
 
@@ -741,7 +768,11 @@ class FVC:
             try:
                 proc_hdus[1].header.extend(self.fvc_transform.getMetadata())
             except Exception as err:
-                self.log(f"Cannot get FVCTransform metadata: {err}", logging.WARNING)
+                self.log(
+                    f"Cannot get FVCTransform metadata: {err}",
+                    logging.WARNING,
+                    broadcast=broadcast,
+                )
 
         posangles = None
         if self.fps:
@@ -797,7 +828,7 @@ class FVC:
 
         await run_in_executor(proc_hdus.writeto, new_filename, checksum=True)
 
-        self.log(f"Processed HDU written to {new_filename}")
+        self.log(f"Processed HDU written to {new_filename}", broadcast=broadcast)
         self.proc_image_path = os.path.abspath(new_filename)
 
         return proc_hdus
@@ -877,11 +908,12 @@ class FVC:
         self.correction_applied = True
         self.log("Correction applied.")
 
-    async def write_summary_F(
+    def write_summary_F(
         self,
         path: str | pathlib.Path | None = None,
         plot: bool = True,
         extra_headers: dict = {},
+        broadcast: bool = False,
     ):
         """Updates data with the last measured positions and write confSummaryF."""
 
@@ -891,7 +923,7 @@ class FVC:
         if self.fibre_data is None:
             raise FVCError("No fibre data.")
 
-        self.log("Updating coordinates.", level=logging.DEBUG)
+        self.log("Updating coordinates.", level=logging.DEBUG, broadcast=broadcast)
 
         fdata = (
             self.fibre_data.reset_index()
@@ -940,10 +972,11 @@ class FVC:
             "fvc_90_perc": self.perc_90,
             "fvc_percent_reached": self.fvc_percent_reached,
             "fvc_image_path": self.proc_image_path if self.proc_image_path else "",
+            "temperature": self.ieb_data.get("TEMPT3", -999.0),
         }
         headers.update(extra_headers)
 
-        await configuration_copy.write_summary(
+        configuration_copy.write_summary(
             path=path,
             flavour="F",
             headers=headers,
@@ -957,9 +990,10 @@ class FVC:
                     "Configuration does not have boresight set. "
                     "Cannot produce FVC plots.",
                     level=logging.WARNING,
+                    broadcast=broadcast,
                 )
             else:
-                self.log("Creating FVC plots", level=logging.DEBUG)
+                self.log("Creating FVC plots", level=logging.DEBUG, broadcast=broadcast)
 
                 outpath = str(self.proc_image_path).replace(".fits", "_distances.pdf")
 
